@@ -8,6 +8,7 @@
 #define __publib_cfg_h_included
 
 #include <publib/alloc.h>
+#include <stdio.h>
 
 enum cfg_type {
 	CFG_LONG,
@@ -23,7 +24,23 @@ enum cfg_type {
 enum cfg_flags {
 	cfg_read_only = 0x01,
 	cfg_saved = 0x02,
-	cfg_set_from_array = 0x04
+	cfg_set_from_array = 0x04,
+	cfg_removed = 0x08,
+	cfg_userflag1 = 0x100,
+	cfg_userflag2 = 0x200,
+	cfg_userflag3 = 0x400,
+	cfg_userflag4 = 0x800,
+	cfg_userflag5 = 0x1000,
+	cfg_userflag6 = 0x2000,
+	cfg_userflag7 = 0x4000,
+	cfg_userflag8 = 0x8000
+};
+
+struct cfg_unknown_variable {
+	char *cfg_name;
+	char *cfg_value;
+	unsigned cfg_flags;
+	struct cfg_unknown_variable *cfg_next;
 };
 
 struct cfg_variable {
@@ -32,17 +49,18 @@ struct cfg_variable {
 	void *cfg_value;
 	unsigned cfg_flags;
 	int cfg_option;
-#if 0
-	/* these are ideas for new functionality */
-	unsigned cfg_modified:1;
-	int (*cfg_is_ok)(void *);
-#endif
 };
 
 const char *cfg_error(void);
 int cfg_from_array(struct cfg_variable *, char **);
 int cfg_read_file(struct cfg_variable *, const char *);
+int cfg_read_open_file(struct cfg_variable *, const char *, FILE *);
 int cfg_write_file(struct cfg_variable *, const char *);
+int cfg_write_open_file(struct cfg_variable *, const char *, FILE *);
 int cfg_rewrite_file(struct cfg_variable *, const char *);
 
+struct cfg_unknown_variable *cfg_find_unknown(struct cfg_variable *,
+						const char *);
+void cfg_reset_some_flags(struct cfg_variable *, unsigned);
+
 #endif
